package com.engine.mzg.service.impl;

import com.engine.core.impl.Service;
import com.engine.mzg.entity.SyncTableField;
import com.engine.mzg.exception.CustomizeRunTimeException;
import com.engine.mzg.service.RecruitMobileService;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import weaver.conn.RecordSet;
import weaver.formmode.mzg.modeexpand.disc.AddDiscExpand;
import weaver.general.Util;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.regex.Matcher;

/**
 * @author:dxfeng
 * @createTime: 2024/09/04
 * @version: 1.0
 */
public class RecruitMobileServiceImpl extends Service implements RecruitMobileService {
    @Override
    public Map<String, Object> submitDiscTest(Map<String, Object> params) {
        String billId = Util.null2String(params.get("billId"));
        // 更新DISC表中，统计各项汇总
        RecordSet rs = new RecordSet();
        rs.executeQuery("select * from uf_recruit_disc where id = ? ", billId);
        if (rs.next()) {
            int countD = 0;
            int countI = 0;
            int countS = 0;
            int countC = 0;
            String[] columnNames = rs.getColumnName();
            for (String columnName : columnNames) {
                Matcher matcher = AddDiscExpand.PATTERN.matcher(columnName);
                if (matcher.matches()) {
                    String value = rs.getString(columnName);
                    if ("0".equals(value)) {
                        countD++;
                    } else if ("1".equals(value)) {
                        countI++;
                    } else if ("2".equals(value)) {
                        countS++;
                    } else if ("3".equals(value)) {
                        countC++;
                    }
                }
            }
            rs.executeUpdate("update uf_recruit_disc set dxhj = ? ,ixhj = ?, sxhj = ?, cxhj = ? where id = ? ", countD, countI, countS, countC, billId);
        } else {
            throw new CustomizeRunTimeException("数据异常，提交失败，请联系HR");
        }
        return null;
    }

    @Override
    public Map<String, Object> submitRegist(Map<String, Object> params) {
        // 判断是否已经创建面试台账，未创建则插入数据，已创建则更新数据，发起面试流程后，不允许再次提交
        String billId = Util.null2String(params.get("billId"));
        String targetTable = Util.null2String(params.get("targetTable"));
        String sourceTable = Util.null2String(params.get("sourceTable"));
        RecordSet rs = new RecordSet();
        rs.executeQuery("select id,mslcid from uf_recruit_ms where ypdjid = ? ", billId);
        String msId = "";
        String mslcId = "";
        if (rs.next()) {
            msId = rs.getString("id");
            mslcId = rs.getString("mslcid");
        }
        // 是否新增面试数据
        boolean isAdd = StringUtils.isBlank(msId);
        if (StringUtils.isNotBlank(mslcId)) {
            throw new CustomizeRunTimeException("当前数据已登记结束，无法重复提交");
        }
        rs.executeQuery("select * from uf_recruit_table where target_table = ? and source_table =? ", targetTable, sourceTable);
        String mainId = "";
        if (rs.next()) {
            mainId = rs.getString("id");
        }
        if (StringUtils.isNotBlank(mainId)) {
            // 查询配置的字段，更新或者插入数据
            rs.executeQuery("select * from uf_recruit_table_dt1 where mainid = ? ", mainId);
            List<SyncTableField> fields = new ArrayList<>();
            while (rs.next()) {
                fields.add(SyncTableField.builder().sourceField(rs.getString("source_field")).targetField(rs.getString("target_field")).build());
            }
            if(CollectionUtils.isNotEmpty(fields)){
                throw new CustomizeRunTimeException("数据同步配置异常，请检查配置");
            }
        }


        return null;
    }
}
